@@ -9,8 +9,8 @@
 #include "version.h"
 
 #include <QApplication>
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
 
 #include <KAboutData>
 #include <KDBusService>
@@ -22,16 +22,20 @@ int main(int argc, char *argv[])
 
     KAboutData aboutData(QStringLiteral("bluedevilsendfile"),
                          i18n("Bluetooth Send File Wizard"),
-                         BLUEDEVIL_VERSION,
+                         QStringLiteral(BLUEDEVIL_VERSION_STRING),
                          i18n("Bluetooth Send File Wizard"),
                          KAboutLicense::GPL,
                          i18n("(c) 2010, UFO Coders"));
 
-    aboutData.addAuthor(QStringLiteral("David Rosca"), i18n("Maintainer"),
-                        QStringLiteral("nowrep@gmail.com"), QStringLiteral("http://david.rosca.cz"));
+    aboutData.addAuthor(QStringLiteral("David Rosca"), //
+                        i18n("Maintainer"),
+                        QStringLiteral("nowrep@gmail.com"),
+                        QStringLiteral("http://david.rosca.cz"));
 
-    aboutData.addAuthor(QStringLiteral("Alejandro Fiestas Olivares"), i18n("Previous Maintainer"),
-                        QStringLiteral("afiestas@kde.org"), QStringLiteral("http://www.afiestas.org/"));
+    aboutData.addAuthor(QStringLiteral("Alejandro Fiestas Olivares"),
+                        i18n("Previous Maintainer"),
+                        QStringLiteral("afiestas@kde.org"),
+                        QStringLiteral("http://www.afiestas.org/"));
 
     app.setAttribute(Qt::AA_UseHighDpiPixmaps);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-system-bluetooth")));
